Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(99)

Unified Diff: chrome/browser/browser.cc

Issue 4524002: First cut of the about:conflicts page, listing all DLLs loaded in the Chrome ... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/browser.cc
===================================================================
--- chrome/browser/browser.cc (revision 65039)
+++ chrome/browser/browser.cc (working copy)
@@ -1724,6 +1724,11 @@
ShowSingletonTab(GURL(chrome::kChromeUIExtensionsURL));
}
+void Browser::ShowAboutConflictsTab() {
+ UserMetrics::RecordAction(UserMetricsAction("AboutConflicts"), profile_);
+ ShowSingletonTab(GURL(chrome::kChromeUIConflictsURL));
+}
+
void Browser::ShowBrokenPageTab(TabContents* contents) {
UserMetrics::RecordAction(UserMetricsAction("ReportBug"), profile_);
string16 page_title = contents->GetTitle();
@@ -2200,6 +2205,7 @@
case IDC_IMPORT_SETTINGS: OpenImportSettingsDialog(); break;
case IDC_ABOUT: OpenAboutChromeDialog(); break;
case IDC_UPGRADE_DIALOG: OpenUpdateChromeDialog(); break;
+ case IDC_VIEW_INCOMPATIBILITIES: ShowAboutConflictsTab(); break;
case IDC_HELP_PAGE: OpenHelpTab(); break;
#if defined(OS_CHROMEOS)
case IDC_SYSTEM_OPTIONS: OpenSystemOptionsDialog(); break;
@@ -3069,7 +3075,6 @@
}
void Browser::ShowContentSettingsWindow(ContentSettingsType content_type) {
-
if (CommandLine::ForCurrentProcess()->HasSwitch(
switches::kEnableTabbedOptions)) {
ShowOptionsTab(
@@ -3482,9 +3487,11 @@
// Show various bits of UI
command_updater_.UpdateCommandEnabled(IDC_CLEAR_BROWSING_DATA, normal_window);
// The upgrade entry should always be enabled. Whether it is visible is a
// separate matter determined on menu show.
command_updater_.UpdateCommandEnabled(IDC_UPGRADE_DIALOG, true);
+ command_updater_.UpdateCommandEnabled(IDC_VIEW_INCOMPATIBILITIES, true);
// Initialize other commands whose state changes based on fullscreen mode.
UpdateCommandsForFullscreenMode(false);
@@ -3482,9 +3487,11 @@
// Show various bits of UI
command_updater_.UpdateCommandEnabled(IDC_CLEAR_BROWSING_DATA, normal_window);
- // The upgrade entry should always be enabled. Whether it is visible is a
- // separate matter determined on menu show.
+ // The upgrade entry and the view incompatibility entry should always be
+ // enabled. Whether they are visible is a separate matter determined on menu
+ // show.
command_updater_.UpdateCommandEnabled(IDC_UPGRADE_DIALOG, true);

Powered by Google App Engine
This is Rietveld 408576698